==> mathjax_2.7.0.orig.tar.xz: MathJax-2.7.0/unpacked/localization/ko/HelpDialog.js <==
/*************************************************************
 *
 *  MathJax/localization/ko/HelpDialog.js
 *
 *  Copyright (c) 2009-2016 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("ko","HelpDialog",{
        version: "2.7.0",
        isLoaded: true,
        strings: {
          Help: "MathJax \uB3C4\uC6C0\uB9D0",
          Browsers: "*\uBE0C\uB77C\uC6B0\uC800*: MathJax\uB294 IE6+, Firefox 3+, Chrome 0.2+, Safari 2+, Opera 9.6+\uB97C \uD3EC\uD568\uD558\uB294 \uBAA8\uB4E0 \uCD5C\uC2E0 \uBE0C\uB77C\uC6B0\uC800\uC640 \uB300\uBD80\uBD84\uC758 \uBAA8\uBC14\uC77C \uBE0C\uB77C\uC6B0\uC800\uC5D0\uC11C \uC791\uB3D9\uD569\uB2C8\uB2E4.",
          Menu: "*\uC218\uC2DD \uBA54\uB274*: MathJax\uB294 \uBC29\uC815\uC2DD\uC5D0 \uCEE8\uD14D\uC2A4\uD2B8 \uBA54\uB274\uB97C \uB367\uBD99\uC785\uB2C8\uB2E4. \uBA54\uB274\uC5D0 \uC811\uADFC\uD558\uB824\uBA74 \uC544\uBB34 \uC218\uC2DD\uC744 \uC67C\uCABD \uD074\uB9AD\uD558\uAC70\uB098 \uC624\uB978\uCABD \uD074\uB9AD\uD558\uC138\uC694.",
          Zoom: "*\uC218\uC2DD \uD655\uB300*: \uBC29\uC815\uC2DD\uC744 \uC77D\uB294 \uB370 \uC5B4\uB824\uC6C0\uC774 \uC788\uB2E4\uBA74, MathJax\uC5D0\uC11C \uBC29\uC815\uC2DD\uC744 \uB354 \uC798 \uBCFC \uC218 \uC788\uB3C4\uB85D \uC2DD\uC744 \uD06C\uAC8C \uB9CC\uB4E4 \uC218 \uC788\uC2B5\uB2C8\uB2E4.",
          MathJax: "*MathJax*\uB294 \uBB38\uC11C \uC791\uC131\uC790\uAC00 \uC6F9 \uD398\uC774\uC9C0\uC5D0 \uC218\uD559\uC744 \uD3EC\uD568\uD560 \uC218 \uC788\uB3C4\uB85D \uD574\uC8FC\uB294 JavaScript \uB77C\uC774\uBE0C\uB7EC\uB9AC\uC785\uB2C8\uB2E4. \uBB38\uC11C\uB97C \uC77D\uAE30 \uC704\uD574 \uB3C5\uC790\uAC00 \uB530\uB85C \uD574\uC57C \uD558\uB294 \uAC83\uC740 \uC5C6\uC2B5\uB2C8\uB2E4.",
          Language: "*Language* \uBA54\uB274\uC5D0\uC11C MathJax\uAC00 \uBA54\uB274\uC640 \uACBD\uACE0 \uBA54\uC2DC\uC9C0\uB85C\uC368 \uC0AC\uC6A9\uD558\uB294 \uC5B8\uC5B4\uB97C \uC120\uD0DD\uD560 \uC218 \uC788\uC2B5\uB2C8\uB2E4."
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/ko/HelpDialog.js");

==> mathjax_2.7.3+dfsg.orig.tar.xz: MathJax-2.7.3/unpacked/localization/ko/HelpDialog.js <==
/*************************************************************
 *
 *  MathJax/localization/ko/HelpDialog.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("ko","HelpDialog",{
        version: "2.7.3",
        isLoaded: true,
        strings: {
          Help: "MathJax \uB3C4\uC6C0\uB9D0",
          Browsers: "*\uBE0C\uB77C\uC6B0\uC800*: MathJax\uB294 IE6+, Firefox 3+, Chrome 0.2+, Safari 2+, Opera 9.6+\uB97C \uD3EC\uD568\uD558\uB294 \uBAA8\uB4E0 \uCD5C\uC2E0 \uBE0C\uB77C\uC6B0\uC800\uC640 \uB300\uBD80\uBD84\uC758 \uBAA8\uBC14\uC77C \uBE0C\uB77C\uC6B0\uC800\uC5D0\uC11C \uC791\uB3D9\uD569\uB2C8\uB2E4.",
          Menu: "*\uC218\uC2DD \uBA54\uB274*: MathJax\uB294 \uBC29\uC815\uC2DD\uC5D0 \uCEE8\uD14D\uC2A4\uD2B8 \uBA54\uB274\uB97C \uB367\uBD99\uC785\uB2C8\uB2E4. \uBA54\uB274\uC5D0 \uC811\uADFC\uD558\uB824\uBA74 \uC544\uBB34 \uC218\uC2DD\uC744 \uC67C\uCABD \uD074\uB9AD\uD558\uAC70\uB098 \uC624\uB978\uCABD \uD074\uB9AD\uD558\uC138\uC694.",
          Zoom: "*\uC218\uC2DD \uD655\uB300*: \uBC29\uC815\uC2DD\uC744 \uC77D\uB294 \uB370 \uC5B4\uB824\uC6C0\uC774 \uC788\uB2E4\uBA74, MathJax\uC5D0\uC11C \uBC29\uC815\uC2DD\uC744 \uB354 \uC798 \uBCFC \uC218 \uC788\uB3C4\uB85D \uC2DD\uC744 \uD06C\uAC8C \uB9CC\uB4E4 \uC218 \uC788\uC2B5\uB2C8\uB2E4.",
          MathJax: "*MathJax*\uB294 \uBB38\uC11C \uC791\uC131\uC790\uAC00 \uC6F9 \uD398\uC774\uC9C0\uC5D0 \uC218\uD559\uC744 \uD3EC\uD568\uD560 \uC218 \uC788\uB3C4\uB85D \uD574\uC8FC\uB294 JavaScript \uB77C\uC774\uBE0C\uB7EC\uB9AC\uC785\uB2C8\uB2E4. \uBB38\uC11C\uB97C \uC77D\uAE30 \uC704\uD574 \uB3C5\uC790\uAC00 \uB530\uB85C \uD574\uC57C \uD558\uB294 \uAC83\uC740 \uC5C6\uC2B5\uB2C8\uB2E4.",
          Language: "*Language* \uBA54\uB274\uC5D0\uC11C MathJax\uAC00 \uBA54\uB274\uC640 \uACBD\uACE0 \uBA54\uC2DC\uC9C0\uB85C\uC368 \uC0AC\uC6A9\uD558\uB294 \uC5B8\uC5B4\uB97C \uC120\uD0DD\uD560 \uC218 \uC788\uC2B5\uB2C8\uB2E4.",
          CloseDialog: "\uB3C4\uC6C0\uB9D0 \uB300\uD654 \uC0C1\uC790 \uB2EB\uAE30"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/ko/HelpDialog.js");
